"""
Extractors for different documentation types.

Each extractor converts a specific source type into DocElements.
"""

from bengal.autodoc.extractors.python import PythonExtractor

__all__ = ["PythonExtractor"]
