{#
  Reference Documentation Header

  Unified header component for all reference documentation types (API, CLI, OpenAPI, etc.)

  Parameters:
    - icon: Icon/emoji to display (e.g., '📦', '⌨️', '🔌')
    - title: Page title
    - description: Optional lead description
    - type: Reference type for CSS class ('api', 'cli', 'openapi', etc.)

  Usage:
    {% set icon = '📦' %}
    {% set title = page.title %}
    {% set description = page.metadata.get('description', '') %}
    {% set type = 'api' %}
    {% include 'partials/reference-header.html' %}
#}

<div class="reference-header">
  <span class="reference-icon">{{ icon | default('📄') }}</span>
  <h1>{{ title }}</h1>
</div>

{% if description %}
<p class="lead">{{ description }}</p>
{% endif %}
