/**
 * Bengal SSG Default Theme
 * Footer Styles
 */

/* ============================================
   SITE FOOTER
   ============================================ */

footer[role="contentinfo"] {
  margin-top: var(--space-16);
  padding: var(--space-8) 0;
  border-top: 1px solid var(--color-border);
  background-color: var(--color-bg-secondary);
}

footer .container {
  display: flex;
  flex-direction: column;
  gap: var(--space-6);
}

@media (min-width: 768px) {
  footer .container {
    flex-direction: row;
    justify-content: space-between;
    align-items: center;
  }
}

/* ============================================
   FOOTER CONTENT
   ============================================ */

.footer-copyright {
  font-size: var(--text-sm);
  color: var(--color-text-secondary);
}

.footer-links {
  display: flex;
  gap: var(--space-4);
  margin: 0;
  padding: 0;
  list-style: none;
}

.footer-links a {
  font-size: var(--text-sm);
  color: var(--color-text-secondary);
  text-decoration: none;
  transition: color var(--transition-fast) var(--ease-out);
}

.footer-links a:hover {
  color: var(--color-primary);
}

/* ============================================
   FOOTER SECTIONS
   ============================================ */

.footer-grid {
  display: grid;
  gap: var(--space-8);
  grid-template-columns: 1fr;
}

@media (min-width: 640px) {
  .footer-grid {
    grid-template-columns: repeat(2, 1fr);
  }
}

@media (min-width: 1024px) {
  .footer-grid {
    grid-template-columns: repeat(4, 1fr);
  }
}

.footer-section h3 {
  margin-bottom: var(--space-4);
  font-size: var(--text-base);
  font-weight: var(--font-semibold);
  color: var(--color-text-primary);
}

.footer-section ul {
  display: flex;
  flex-direction: column;
  gap: var(--space-2);
  margin: 0;
  padding: 0;
  list-style: none;
}

.footer-section a {
  font-size: var(--text-sm);
  color: var(--color-text-secondary);
  text-decoration: none;
  transition: color var(--transition-fast) var(--ease-out);
}

.footer-section a:hover {
  color: var(--color-primary);
}

/* ============================================
   SOCIAL LINKS
   ============================================ */

.social-links {
  display: flex;
  gap: var(--space-3);
  margin: 0;
  padding: 0;
  list-style: none;
}

.social-links a {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 36px;
  height: 36px;
  color: var(--color-text-secondary);
  background-color: var(--color-bg-tertiary);
  border-radius: var(--radius-md);
  text-decoration: none;
  transition: all var(--transition-fast) var(--ease-out);
}

.social-links a:hover {
  color: var(--color-text-inverse);
  background-color: var(--color-primary);
}

.social-links svg {
  width: 18px;
  height: 18px;
}
